@@ -1,4 +1,15 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import re
 import types
@@ -132,7 +143,8 @@ class MongoDb(AgentCheck):
             self.log.error(
                 'mongo.yaml exists but pymongo module can not be imported. Skipping check.')
             raise Exception(
-                'Python PyMongo Module can not be imported. Please check the installation instruction on the Datadog Website')
+                'Python PyMongo Module can not be imported. Please check the installation '
+                'instruction on the Datadog Website')
 
         try:
             from pymongo import uri_parser
@@ -194,7 +206,8 @@ class MongoDb(AgentCheck):
                         data['replicationLag'] = lag.total_seconds()
                     else:
                         data['replicationLag'] = (
-                            lag.microseconds + (lag.seconds + lag.days * 24 * 3600) * 10 ** 6) / 10.0 ** 6
+                            lag.microseconds + (
+                                lag.seconds + lag.days * 24 * 3600) * 10 ** 6) / 10.0 ** 6
 
                 if current is not None:
                     data['health'] = current['health']
