@@ -18,9 +18,9 @@ import copy
 import json
 import logging
 
-from osc_lib import exceptions
-
+from keystoneauth1.exceptions import base as keystoneauth_exception
 from monascaclient import client
+from osc_lib import exceptions
 
 from monasca_agent.common import keystone
 
@@ -136,27 +136,30 @@ class MonascaAPI(object):
             self._post(tenant_group[tenant], tenant)
 
     def _get_mon_client(self):
-        k = keystone.Keystone(self._config)
-        endpoint = k.get_monasca_url()
-        session = k.get_session()
-        c = client.Client(
-            api_version=self._api_version,
-            endpoint=endpoint,
-            session=session,
-            timeout=self.write_timeout,
-            **keystone.get_args(self._config)
-        )
-        return c
+        try:
+            k = keystone.Keystone(self._config)
+            endpoint = k.get_monasca_url()
+            session = k.get_session()
+            c = client.Client(
+                api_version=self._api_version,
+                endpoint=endpoint,
+                session=session,
+                timeout=self.write_timeout,
+                **keystone.get_args(self._config)
+            )
+            return c
+        except keystoneauth_exception.ClientException as ex:
+            log.error('Failed to initialize Monasca client. {}'.format(ex))
 
     def _send_message(self, **kwargs):
         try:
             self._mon_client.metrics.create(**kwargs)
             return True
         except exceptions.ClientException as ex:
-                log.exception("ClientException: error sending "
-                              "message to monasca-api.")
-                self._failure_reason = ('Error sending message to '
-                                        'the Monasca API: {0}').format(str(ex))
+            log.exception("ClientException: error sending "
+                          "message to monasca-api.")
+            self._failure_reason = ('Error sending message to '
+                                    'the Monasca API: {0}').format(str(ex))
         except Exception:
             log.exception("Error sending message to Monasca API.")
             self._failure_reason = 'The Monasca API is DOWN or unreachable'
